@@ -8,7 +8,7 @@ var log = require("npmlog")
   , crypto
 
 try {
-  crypto = process.binding("crypto") && require("crypto")
+  crypto = require("crypto")
 } catch (ex) {}
 
 adduser.usage = "npm adduser\nThen enter stuff at the prompts"
@@ -135,7 +135,8 @@ function save (c, u, cb) {
     if (scope.charAt(0) !== "@") scope = "@" + scope
 
     var scopedRegistry = npm.config.get(scope + ":registry")
-    if (scopedRegistry) uri = scopedRegistry
+    var cliRegistry = npm.config.get("registry", "cli")
+    if (scopedRegistry && !cliRegistry) uri = scopedRegistry
   }
 
   var params = {
